.. parver documentation master file

parver documentation
========================

``parver`` is a Python package for parsing and manipulating `PEP 440`_ version
numbers.

.. _`PEP 440`: https://www.python.org/dev/peps/pep-0440/

Contents:

.. toctree::
   :maxdepth: 3

   installation
   usage
   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
